==> SimplyDualWielding-5.1.0%2B1.21.5-Fabric-sources.jar: eva/dualwielding/DualWieldingMain.java <==
package eva.dualwielding;

import eva.dualwielding.access.ServerPlayerAccess;
import eva.dualwielding.access.ServerPlayerGameModeAccess;
import eva.dualwielding.config.JsonConfigHelper;
import eva.dualwielding.init.ParticleInit;
import eva.dualwielding.network.AttackPayload;
import eva.dualwielding.network.ConfigPacket;
import eva.dualwielding.network.ListPacket;
import eva.dualwielding.network.MinePacket;
import net.fabricmc.api.ModInitializer;
import net.fabricmc.fabric.api.networking.v1.PayloadTypeRegistry;
import net.fabricmc.fabric.api.networking.v1.ServerPlayNetworking;
import net.fabricmc.loader.api.FabricLoader;
import net.minecraft.class_3222;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class DualWieldingMain implements ModInitializer {

    public static final String MOD_ID = "sdw";
    public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);

    public static boolean collectiveLoaded = false;

    @Override
    public void onInitialize() {
        JsonConfigHelper.init();
        ParticleInit.initServer();
        collectiveLoaded = FabricLoader.getInstance().isModLoaded("collective");

        PayloadTypeRegistry.configurationS2C().register(ConfigPacket.ID, ConfigPacket.CODEC);
        PayloadTypeRegistry.configurationS2C().register(ListPacket.ID, ListPacket.CODEC);
        PayloadTypeRegistry.playC2S().register(AttackPayload.TYPE, AttackPayload.STREAM_CODEC);
        PayloadTypeRegistry.playC2S().register(MinePacket.MinePayload.TYPE, MinePacket.MinePayload.STREAM_CODEC);

        ServerPlayNetworking.registerGlobalReceiver(AttackPayload.TYPE, (payload, context) -> {
            int entityId = payload.entityId();
            context.server().execute(() -> {
                class_3222 tp = context.player();
                tp.method_14234();
                if (context.player().method_37908().method_8469(entityId) != null) {
                    ((ServerPlayerAccess) tp).dualWielding$attackOffhand(tp.method_37908().method_8469(entityId));
                }
            });
        });

        ServerPlayNetworking.registerGlobalReceiver(MinePacket.MinePayload.TYPE, (payload, context) -> {
            context.server().execute(() -> {
                class_3222 tp = context.player();
                ((ServerPlayerGameModeAccess)tp.field_13974).dualWielding$handleBlockBreakingAction(payload.pos(), payload.action(), payload.direction(), tp.method_37908().method_31600(), payload.sequence());
                    tp.field_13987.method_41255(payload.sequence());
            });
        });
    }
}

==> SimplyDualWielding-5.1.1%2B1.21.1-Fabric-sources.jar: eva/dualwielding/DualWieldingMain.java <==
package eva.dualwielding;

import eva.dualwielding.access.ServerPlayerAccess;
import eva.dualwielding.access.ServerPlayerGameModeAccess;
import eva.dualwielding.config.JsonConfigHelper;
import eva.dualwielding.init.ParticleInit;
import eva.dualwielding.network.AttackPayload;
import eva.dualwielding.network.ConfigPacket;
import eva.dualwielding.network.ListPacket;
import eva.dualwielding.network.MinePacket;
import net.fabricmc.api.ModInitializer;
import net.fabricmc.fabric.api.networking.v1.PayloadTypeRegistry;
import net.fabricmc.fabric.api.networking.v1.ServerPlayNetworking;
import net.fabricmc.loader.api.FabricLoader;
import net.minecraft.class_3222;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class DualWieldingMain implements ModInitializer {

    public static final String MOD_ID = "sdw";
    public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);

    public static boolean collectiveLoaded = false;

    @Override
    public void onInitialize() {
        JsonConfigHelper.init();
        ParticleInit.initServer();
        collectiveLoaded = FabricLoader.getInstance().isModLoaded("collective");

        PayloadTypeRegistry.configurationS2C().register(ConfigPacket.ID, ConfigPacket.CODEC);
        PayloadTypeRegistry.configurationS2C().register(ListPacket.ID, ListPacket.CODEC);
        PayloadTypeRegistry.playC2S().register(AttackPayload.TYPE, AttackPayload.STREAM_CODEC);
        PayloadTypeRegistry.playC2S().register(MinePacket.MinePayload.TYPE, MinePacket.MinePayload.STREAM_CODEC);

        ServerPlayNetworking.registerGlobalReceiver(AttackPayload.TYPE, (payload, context) -> {
            int entityId = payload.entityId();
            context.server().execute(() -> {
                class_3222 tp = context.player();
                tp.method_14234();
                if (context.player().method_37908().method_8469(entityId) != null) {
                    ((ServerPlayerAccess) tp).dualWielding$attackOffhand(tp.method_37908().method_8469(entityId));
                }
            });
        });

        ServerPlayNetworking.registerGlobalReceiver(MinePacket.MinePayload.TYPE, (payload, context) -> {
            context.server().execute(() -> {
                class_3222 tp = context.player();
                ((ServerPlayerGameModeAccess)tp.field_13974).dualWielding$processBlockBreakingAction(payload.pos(), payload.action(), payload.direction(), tp.method_37908().method_31600(), payload.sequence());
                    tp.field_13987.method_41255(payload.sequence());
            });
        });
    }
}
